@@ -1,8 +1,8 @@
-# Copyright (c) 2020-2023 Nuno Fachada
+# Copyright (c) 2020-2025 Nuno Fachada
 # Distributed under the MIT License (http://opensource.org/licenses/MIT)
 
 test_that("Package linting", {
-  # Don't do linting on CRAN, coverage reporting or testing on CI + Not Windows
+  # Don't do linting on CRAN or coverage reporting
   skip_if(is_test_mode("cran"))
   skip_on_cran()
   skip_on_covr()
@@ -15,9 +15,6 @@ test_that("Package linting", {
   lintr::expect_lint_free(
     path = pkgpath,
     linters = lintr::linters_with_defaults(
-      # The clugen() function has a large cyclomatic complexity
-      # so let's increase this a bit
-      cyclocomp_linter = lintr::cyclocomp_linter(complexity_limit = 60),
       # The official line length for this package is 80, but lets
       # give it some margin; also, Windows complains about the 80
       # limit due to not recognizing some UTF-8 characters.
